This is intended for use with RGB(A) rasters (e.g., georeferenced imagery or photos). To work with
bands as if they were columns, use df_spatial() and ggplot2::geom_raster().
# S3 method for class 'stars'
layer_spatial(
data,
mapping = NULL,
interpolate = NULL,
is_annotation = FALSE,
lazy = FALSE,
dpi = 150,
options = character(0),
...
)
# S3 method for class 'stars'
annotation_spatial(data, mapping = NULL, interpolate = NULL, ...)
StatSpatialStars
StatSpatialStarsAnnotation
StatSpatialStarsDf
GeomSpatialStarsA stars object
Currently, only RGB or RGBA rasters are supported. In the future, one may be able to map specific bands to the fill and alpha aesthetics.
Interpolate resampling for rendered raster image
Lets raster exist without modifying scales
Delay projection and resample of raster until the plot is being rendered
if lazy = TRUE, the dpi to which the raster should be resampled
GDAL options for warping/resampling (see st_warp)
Passed to other methods
A ggplot2 layer
# \donttest{
library(ggplot2)
load_longlake_data(
which = c(
"longlake_osm",
"longlake_depth_raster"
),
raster_format = "stars"
)
#> Registered S3 method overwritten by 'stars':
#> method from
#> st_interpolate_aw.stars sf
ggplot() +
layer_spatial(longlake_osm)
ggplot() +
layer_spatial(longlake_depth_raster) +
scale_fill_continuous(
na.value = NA,
type = "viridis"
)
#> Warning: Removed 6584 rows containing missing values or values outside the scale range
#> (`geom_raster()`).
# }